bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaARD.lower_bound_contribution
====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaARD.lower_bound_contribution